        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 18 <br>5,7,8,10,13,16,24,26,31,32,33,34,35,38,40,44,47,48';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 15 <strong>control</strong><br>0,9,12,17,21,22,27,28,36,39,42,43,45,49,50';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>46</strong> miembros: 15 <br>1,3,4,6,11,14,15,18,19,20,29,30,37,41,46';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260814 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>23</strong> miembros: 3 <br>2,23,25';}
}
